@@ -6,7 +6,7 @@ use I18N::LangTags ();
 use I18N::LangTags::Detect ();
 use 5.008;
 
-our $VERSION = '0.00024';
+our $VERSION = '0.00025';
 our $AUTHORITY = 'cpan:DMAKI';
 
 BEGIN {
@@ -46,7 +46,7 @@ has _fallback_languages => (
     is => 'rw',
     lazy => 1,
     builder => "_build__fallback_languages",
-    init_arg => 'languages',
+    init_arg => 'fallback_languages',
 );
 
 has _localizers => (
@@ -85,6 +85,7 @@ has localizer_map => (
 
 sub BUILD {
     my $self = shift;
+
     if ($self->count_localizers > 0) {
         foreach my $loc (@{ $self->_localizers }) {
             $loc->register($self);
@@ -204,6 +205,7 @@ sub localize {
         }
         foreach my $localizer (@$localizers) {
             if (DEBUG) {
+                local $Log::Minimal::AUTODUMP = 1;
                 debugf("localize - Trying with %s", $localizer);
             }
             my $out = $localizer->localize_for(
@@ -273,11 +275,16 @@ sub add_localizer {
         $localizer = $_[0];
     } else {
         my %args = @_;
+
         my $klass = delete $args{class};
         if ($klass !~ s/^\+//) {
             $klass = "Data::Localize::$klass";
         }
         Module::Load::load($klass);
+        if (Data::Localize::DEBUG) {
+            local $Log::Minimal::AUTODUMP = 1;
+            debugf("Creating localizer '%s' (%s)", $klass, \%args);
+        }
         $localizer = $klass->new(%args);
     }
 
