@@ -1,11 +1,8 @@
 package Data::Localize::Format;
-use Any::Moose;
-no Any::Moose;
+use Moo;
 
 sub format { Carp::confess("format() must be overridden") }
 
-__PACKAGE__->meta->make_immutable();
-
 1;
 
 __END__
