@@ -2,6 +2,7 @@ package Data::Localize::MultiLevel;
 use Moo;
 use Config::Any;
 use Data::Localize;
+use MooX::Types::MooseLike::Base qw(ArrayRef);
 BEGIN {
     if (Data::Localize::DEBUG) {
         require Data::Localize::Log;
@@ -14,13 +15,23 @@ with 'Data::Localize::Trait::WithStorage';
 
 has paths => (
     is => 'ro',
-    isa => 'ArrayRef',
+    isa => ArrayRef,
     trigger => sub {
         my $self = shift;
-        $self->load_from_path($_) for @{$_[0]};
+        if ($self->initialized) {
+            $self->load_from_path($_) for @{$_[0]};
+        }
     },
 );
 
+after BUILD => sub {
+    my $self = shift;
+    my $paths = $self->paths;
+    foreach my $path (@$paths) {
+        $self->load_from_path($path);
+    }
+};
+
 after register => sub {
     my ($self, $loc) = @_;
     $loc->add_localizer_map('*', $self);
